    bytearray:
    all:
    set:
    page_title:./about/introspect.html
    int:
    pow:
    float:
    reduce:
    lipsum:
    issubclass:
    divmod:
    unicode:
    enumerate:
    isinstance:
    any:
    locals:
    slice:
    zip:
    min:
    sum:
    format:
    hex:
    complex:
    long:
    id:
    content:
    source:./about/introspect.html
    chr:
    abs:
    dict:
    xrange:
    bool:
    oct:
    bin:
    map:
    wrapper:
    tuple:
    max:
    reversed:
    repr:
    len:
    callable:
    sorted:
    ord:
    hasattr:
    template_source:./about/_introspect_template.html
    list:
    iter:
    filter:
    range:
    str:
    cycler:
    joiner:
    navigation:
      directories : [Doc:index.html|pyg, {'about': [Doc:about/index.md|jinja|markdown, {}]}]
      current_index : None
    round:
    dir:
    cmp: